//
//  ViewController.m
//  AAI Demo
//
//  Created by joycefang on 2019/4/3.
//  Copyright © 2019年 Tencent. All rights reserved.
//

#import "ViewController.h"
#import "QCloudTTS.h"
#import "DropdownListView.h"
#import <AVFoundation/AVFoundation.h>

#define SCREEN_WIDTH  ([[UIScreen mainScreen] bounds].size.width)

@interface ViewController ()<QCloudTTSDelegate>
{
    UIButton*   _btnStartTTS;
    UIButton*   _btnStopTTS;
    UIButton*   _btnPauseTTS;
    UIButton*   _btnResumeTTS;
    UITextView*  _textField;   //输入想说的话
    
    NSInteger _speedType;
    NSInteger _voiceType;
    NSInteger _languageType;
    
    QCloudTTSConfig *_config;
}

@property (nonatomic, strong) QCloudTTS* qcloudTTSObj;

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    [self initSDK];
    [self initUI];
    
    //默认
    _speedType = SpeedTypeNormal;
    _voiceType = VoiceTypeAffinityFemale;
    _languageType = PrimaryChinese;

    NSLog(@"SDK version:%@", libQCloudTTSSDKVersionString);
    [[AVAudioSession sharedInstance] setCategory:AVAudioSessionCategoryPlayback error:nil];
    [[AVAudioSession sharedInstance] setActive:YES error:NULL];
}

- (void)initSDK
{
    /* 在使用云API之前，请前往 腾讯云API密钥页面 申请安全凭证。 安全凭证包括 SecretId 和 SecretKey：
     * SecretId 用于标识 API 调用者身份
     * SecretKey 用于加密签名字符串和服务器端验证签名字符串的密钥。
     */
    
    //注意：这里只是示例，请根据用户实际申请的 SecretId 和 SecretKey 进行后续操作！
    NSInteger appId = #replace with you own appid;
    NSString *secretId = #replace with you own secretId;
    NSString *secretKey = #replace with you own secretKey;
    
    _qcloudTTSObj = [[QCloudTTS alloc] initWithAppId:appId secretId:secretId secretKey:secretKey];
    _qcloudTTSObj.ttsDelegate = self;
    
    _config = [QCloudTTSConfig getInstance];
}

- (void)initUI
{
    [self.view setBackgroundColor:[UIColor colorWithRed:245 / 255.0 green:244 / 255.0 blue:248 / 255.0 alpha:1]];
    
    _textField = [[UITextView alloc] initWithFrame:CGRectMake(15, 100, SCREEN_WIDTH - 30, 150)];
    [_textField setBackgroundColor:[UIColor whiteColor]];
    _textField.layer.borderColor = [UIColor grayColor].CGColor;
    _textField.layer.borderWidth =1.0;
    _textField.layer.cornerRadius =5.0;
    //    _textField.borderStyle = UITextBorderStyleLine;
    //    _textField.placeholder = @"点此输入你想说的话";
    _textField.text = @"生育保险待遇不变。生育保险待遇包括《中华人民共和国社会保险法》规定的生育医疗费用和生育津贴，所需资金从职工基本医疗保险基金中支付。生育津贴支付期限按照《女职工劳动保护特别规定》等法律法规规定的产假期限执行。核定调低社保缴费基数。3月26日召开的国务院常务会议，落实降低社会保险费率部署，明确具体配套措施等。会议决定，核定调低社保缴费基数。各地由过去依据城镇非私营单位在岗职工平均工资，改为以本省城镇非私营单位和私营单位加权计算的全口径就业人员平均工资，核定缴费基数上下限，使缴费基数降低。个体工商户和灵活就业人员可在本省平均工资60%—300%之间自愿选择缴费基数。财政部社保司司长符金陵在4月4日举行的国务院政策例行吹风会上表示，降费会减少基金收入，但不会影响养老金的发放。降低养老保险费率在有效减轻企业社保缴费负担的同时，确实会减少养老保险基金收入，加大基金收支压力。但是请大家放心，降费不会造成养老金支付风险。从总量上看，全国养老保险基金整体收大于支，滚存结余不断增加。播放结束。";
    [self.view addSubview:_textField];
    
    __weak typeof(self) weakSelf = self;
    //设置语速
    DropdownListItem *item1 = [[DropdownListItem alloc] initWithItem:@"-2" itemName:@"0.6倍"];
    DropdownListItem *item2 = [[DropdownListItem alloc] initWithItem:@"-1" itemName:@"0.8倍"];
    DropdownListItem *item3 = [[DropdownListItem alloc] initWithItem:@"0" itemName:@"正常语速"];
    DropdownListItem *item4 = [[DropdownListItem alloc] initWithItem:@"1" itemName:@"1.2倍"];
    DropdownListItem *item5 = [[DropdownListItem alloc] initWithItem:@"2" itemName:@"1.4倍"];
    
    DropdownListView *speedListView = [[DropdownListView alloc] initWithDataSource:@[item1, item2, item3, item4,item5]];
    speedListView.frame = CGRectMake(20, 300, 150, 30);
    speedListView.selectedIndex = 2;
    [speedListView setViewBorder:0.5 borderColor:[UIColor grayColor] cornerRadius:2];
    [self.view addSubview:speedListView];
    
    [speedListView setDropdownListViewSelectedBlock:^(DropdownListView *dropdownListView) {
        __strong typeof(self) strongSelf = weakSelf;
        strongSelf->_speedType = [dropdownListView.selectedItem.itemId integerValue];
        
    }];
    
    //设置音色
    DropdownListItem *voiceItem1 = [[DropdownListItem alloc] initWithItem:@"0" itemName:@"亲和女声(默认)"];
    DropdownListItem *voiceItem2 = [[DropdownListItem alloc] initWithItem:@"1" itemName:@"亲和男声"];
    DropdownListItem *voiceItem3 = [[DropdownListItem alloc] initWithItem:@"2" itemName:@"成熟男声"];
    DropdownListItem *voiceItem4 = [[DropdownListItem alloc] initWithItem:@"3" itemName:@"活力男声"];
    DropdownListItem *voiceItem5 = [[DropdownListItem alloc] initWithItem:@"4" itemName:@"温暖女声"];
    DropdownListItem *voiceItem6 = [[DropdownListItem alloc] initWithItem:@"5" itemName:@"情感女声"];
    DropdownListItem *voiceItem7 = [[DropdownListItem alloc] initWithItem:@"6" itemName:@"情感男声"];
    
    DropdownListView *voiceListView = [DropdownListView new];
    voiceListView.dataSource = @[voiceItem1, voiceItem2, voiceItem3, voiceItem4, voiceItem5, voiceItem6, voiceItem7];
    voiceListView.frame = CGRectMake(20, 350, 150, 30);
    voiceListView.selectedIndex = 0;
    [voiceListView setViewBorder:0.5 borderColor:[UIColor grayColor] cornerRadius:2];
    [self.view addSubview:voiceListView];
    
    [voiceListView setDropdownListViewSelectedBlock:^(DropdownListView *dropdownListView) {
        __strong typeof(self) strongSelf = weakSelf;
        strongSelf->_voiceType = [dropdownListView.selectedItem.itemId integerValue];
    }];
    
    //设置语言
    DropdownListItem *item9 = [[DropdownListItem alloc] initWithItem:@"1" itemName:@"中文"];
    DropdownListItem *item10 = [[DropdownListItem alloc] initWithItem:@"2" itemName:@"英文"];
    DropdownListView *languageListView = [DropdownListView new];
    languageListView.dataSource = @[item9, item10];
    languageListView.frame = CGRectMake(20, 400, 150, 30);
    languageListView.selectedIndex = 0;
    [languageListView setViewBorder:0.5 borderColor:[UIColor grayColor] cornerRadius:2];
    [self.view addSubview:languageListView];
    
    [languageListView setDropdownListViewSelectedBlock:^(DropdownListView *dropdownListView) {
        __strong typeof(self) strongSelf = weakSelf;
        strongSelf->_languageType = [dropdownListView.selectedItem.itemId integerValue];
    }];
    
    
    _btnStartTTS = [[UIButton alloc] initWithFrame:CGRectMake(30, 450, 100, 30)];
    [_btnStartTTS setBackgroundColor:[UIColor blueColor]];
    [_btnStartTTS setTitle:@"开始播放" forState:UIControlStateNormal];
    [_btnStartTTS addTarget:self action:@selector(onStartTTSBtn) forControlEvents:UIControlEventTouchDown];
    
    [self.view addSubview:_btnStartTTS];

    _btnStopTTS = [[UIButton alloc] initWithFrame:CGRectMake(30, 520, 100, 30)];
    [_btnStopTTS setBackgroundColor:[UIColor blueColor]];
    [_btnStopTTS setTitle:@"停止播放" forState:UIControlStateNormal];
    [_btnStopTTS addTarget:self action:@selector(onStopTTSBtn) forControlEvents:UIControlEventTouchDown];
    
    [self.view addSubview:_btnStopTTS];
    
    _btnPauseTTS = [[UIButton alloc] initWithFrame:CGRectMake(150, 450, 100, 30)];
    [_btnPauseTTS setBackgroundColor:[UIColor blueColor]];
    [_btnPauseTTS setTitle:@"暂停播放" forState:UIControlStateNormal];
    [_btnPauseTTS addTarget:self action:@selector(onPauseTTSBtn) forControlEvents:UIControlEventTouchDown];
    
    [self.view addSubview:_btnPauseTTS];
    
    _btnResumeTTS = [[UIButton alloc] initWithFrame:CGRectMake(150, 520, 100, 30)];
    [_btnResumeTTS setBackgroundColor:[UIColor blueColor]];
    [_btnResumeTTS setTitle:@"恢复播放" forState:UIControlStateNormal];
    [_btnResumeTTS addTarget:self action:@selector(onResumeTTSBtn) forControlEvents:UIControlEventTouchDown];
    
    [self.view addSubview:_btnResumeTTS];
    
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)onStartTTSBtn   {
    //tts可选配置参数
    _config.projectId = 0;
    _config.speed = _speedType;
    _config.voiceType = _voiceType;
    _config.language = _languageType;
    
    NSString *ttsText = @"第0句、生育保险待遇不变。第1句、生育保险待遇包括《中华人民共和国社会保险法》规定的生育医疗费用和生育津贴。第2句、，，，，第3句、所需资金从职工基本医疗保险基金中支付。第4句、生育津贴支付期限按照《女职工劳动保护特别规定》等法律法规规定的产假期限执行。第5句、核定调低社保缴费基数。播放结束。";

    if (_textField.text && [_textField.text length] > 0) {
        ttsText = _textField.text;
    }
    __weak typeof(self) weakSelf = self;
    [_qcloudTTSObj startTTS:ttsText fail:^(NSString *code, NSString *errMsg) {
        if (errMsg) {
            [weakSelf showWithMessage:errMsg];
        }
    }];
    
}
- (void)onPauseTTSBtn
{
    [_qcloudTTSObj pauseTTS];
}

- (void)onResumeTTSBtn
{
    [_qcloudTTSObj resumeTTS];
}

- (void)onStopTTSBtn
{
    [_qcloudTTSObj stopTTS];
}

- (void)showWithMessage:(NSString *)message{
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"提示"
                                                                   message:message
                                                            preferredStyle:UIAlertControllerStyleAlert];
    UIAlertAction *action = [UIAlertAction actionWithTitle:@"确定" style:UIAlertActionStyleDefault handler:nil];
    [alert addAction:action];
    [self presentViewController:alert animated:YES completion:nil];
}

#pragma mark - QCloudTTSDelegate 代理方法
//开始播放
- (void) onTTSPlayStart{
    NSLog(@"onTTSPlayStart");
}

//音频缓冲中
- (void) onTTSPlayWait{
    NSLog(@"onTTSPlayWait");
}

//缓冲完成，继续播放
- (void) onTTSPlayContinue{
    NSLog(@"onTTSPlayContinue");
}

//恢复播放
- (void) onTTSPlayResume {
    NSLog(@"onTTSPlayResume");
}

//播放中止
- (void) onTTSPlayStop{
    NSLog(@"onTTSPlayStop");
}

//播放结束
- (void) onTTSPlayEnd{
    NSLog(@"onTTSPlayEnd");
}

//当前播放的字符,当前播放的字符在所在的句子中的下标.
- (void) onTTSPlayProgressWithCurrentWord:(NSString *_Nonnull)currentWord
                             currentIndex:(NSInteger )currentIndex{
//    NSLog(@"onTTSPlayProgressWithCurrentWord:%@-----currentIndex:%ld", currentWord, currentIndex);
}

@end
